mylib.DataProcessor
===================

.. currentmodule:: mylib

.. autoclass:: DataProcessor

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataProcessor.__init__
      ~DataProcessor.preview
      ~DataProcessor.run
   
   

   
   
   